---
jupyter:
  kernelspec:
    display_name: Python 3
    language: python
    name: python3
---

```{python}
1+2+3
```

```{python active="", eval=FALSE}
This is a raw cell
```

This is a markdown cell
